#!/bin/bash

################################################################
#
#   Load Libraries
#
################################################################
# Variables set for program defaults
variables (){
    # Program information
    programname="GhostAPT"
    installername="Installer"
    terminalname="Config"
    version="1.1 BETA"
    builddate="built on 5/29/2025"

    # Terminal rules
    terminalwidth="75"

    # Menu structure rules
    invalidselection="Invalid selection."

    # Installation and temp directory
    localtempdirectory="/tmp/GhostAPT"
    localinstalldirectory="$HOME/GhostAPT"

}

# Figures out if the libraries exist, if not it downloads them.
# Dynamic Library Search & Puller

libraryhandler (){
findlibrarycurrentdirectory="$(ls ./ | grep -o "$libraryname" | head -n 1)"

if [ "$findlibrarycurrentdirectory" == $libraryname ]; then
echo "$libraryname found. Loading...
"
source ./$libraryname
else

echo "$libraryname not found in current directory...
"
findtemplibrary="$(ls $localtempdirectory | grep -o "$libraryname" | head -n 1)"

if [ "$findtemplibrary" == $libraryname ]; then
echo "$libraryname found in $localtempdirectory, Loading library...
"
source $localtempdirectory/$libraryname

else

echo "$libraryname not found in $localtempdirectory...
"

findinstalllibrary="$(ls $localinstalldirectory | grep -o "$libraryname" | head -n 1)"

if [ "$findinstalllibrary" == $libraryname ]; then
echo "$libraryname found in $localinstalldirectory, Loading library...
"
source $localinstalldirectory/$libraryname

else
echo "$libraryname not found in $localinstalldirectory, downloading...
"
curl -o $localtempdirectory/$libraryname $remotelibrarylink

echo "
Loading $libraryname...
"
source $localtempdirectory/$libraryname

fi
fi
fi
}

loadlibraries (){

    mkdir $localtempdirectory &>/dev/null

    # Independent Dynamic Variables for Libraries

    libraryname="interface.lib"

    remotelibrarylink="https://assets.jcorestudios.com/GhostAPT/interface.lib"

    libraryhandler

    libraryname="data.lib"

    remotelibrarylink="https://assets.jcorestudios.com/GhostAPT/data.lib"

    libraryhandler

    clear

}

################################################################
#
#   Preloader
#
################################################################

preloader (){

    # Konsole install checker
    konsolecheck (){

    doeskonsoleexist="$(apt list --installed 2>/dev/null | grep -o konsole | head -n 1)"

    if [ "$doeskonsoleexist" == konsole ]; then
    echo "Konsole is installed.
    "
    else
    echo "Konsole is not installed.
    "
    echo "Logging to $HOME/Desktop/GhostAPT_ERRORLOG_README.txt
    "
    date | tee -a $HOME/Desktop/GhostAPT_ERRORLOG_README.txt
    echo "The package 'Konsole' is not installed. You need to open a terminal window and run the command 'sudo apt install konsole' in order to run $programname.
    " | tee -a $HOME/Desktop/GhostAPT_ERRORLOG_README.txt
    echo "Please restart $programname after required packages have been installed.
    "
    sleep 2
    exit
    fi

    }

    # Curl install checker
    curlcheck (){

    doescurlexist="$(apt list --installed 2>/dev/null | grep -o curl | head -n 1)"

    if [ "$doescurlexist" == curl ]; then
    echo "Curl is installed.
    "
    else
    echo "Curl is not installed.
    "
    echo "Logging to $HOME/Desktop/GhostAPT_ERRORLOG_README.txt
    "
    date | tee -a $HOME/Desktop/GhostAPT_ERRORLOG_README.txt
    echo "The package 'Curl' is not installed. You need to open a terminal window and run the command 'sudo apt install curl' in order to run $programname.
    " | tee -a $HOME/Desktop/GhostAPT_ERRORLOG_README.txt
    echo "Please restart $programname after required packages have been installed.
    "
    echo "Launching Konsole to attempt install Curl.
    "
    sleep 1
    konsole -e "sudo apt install curl" &
    exit
    fi

    }

    createprefs (){

    echo "" | tee -a

    }

    # Libraries and Variables
    konsolecheck ; curlcheck ; sleep 1

    echo "Starting up..."

    variables ; loadlibraries

}

################################################################
#
#   installer
#
################################################################
installer (){

variables ; loadlibraries

# Header, credits, prompt ->
header-installer ; sleep 1 ; credits ; entertocontinue

# Notice ->
clear ; header-installer ; sleep 1 ; kdenotice ; entertocontinue

installermenu

konsole -e "./ghostAPT.sh config"

exit

}

################################################################
#
#   Boot Loader
#
################################################################

if [ "$1" == installicons ]; then
variables ; loadlibraries ; createprogshortcuts
exit
fi

if [ "$1" == init ]; then
variables ; loadlibraries ; signatureupdate ; checkforupdates
exit
fi

if [ "$1" == config ]; then
variables ; loadlibraries ; signatureupdate ; ghostconfig
exit
fi

if [ "$1" == install ]; then
installer
else
preloader
# switch script over to konsole and runs installer
konsole -e "./ghostAPT.sh install"
fi

exit
